summaryrefslogtreecommitdiff
path: root/src/parse-gram.c
diff options
context:
space:
mode:
authorAkim Demaille <akim.demaille@gmail.com>2021-02-22 19:13:14 +0100
committerAkim Demaille <akim.demaille@gmail.com>2021-02-25 06:55:08 +0100
commitc61b282d77eb6aea9f08667d78e07bf53863cbb3 (patch)
tree8d4edb0b434db99c16a39cf0e4e6277314e03245 /src/parse-gram.c
parent2d1d2f87f9550c1d575ee1832b462c7a6abc08f1 (diff)
downloadbison-c61b282d77eb6aea9f08667d78e07bf53863cbb3.tar.gz
regen
Diffstat (limited to 'src/parse-gram.c')
-rw-r--r--src/parse-gram.c31
1 files changed, 23 insertions, 8 deletions
diff --git a/src/parse-gram.c b/src/parse-gram.c
index 0ce97a10..95fe43e0 100644
--- a/src/parse-gram.c
+++ b/src/parse-gram.c
@@ -1003,12 +1003,19 @@ do { \
} while (0)
/* YY_LOCATION_PRINT -- Print the location on the stream.
This macro was not mandated originally: define only if we know
we won't break user code: when these are the locations we know. */
-# ifndef YY_LOCATION_PRINT
-# if defined GRAM_LTYPE_IS_TRIVIAL && GRAM_LTYPE_IS_TRIVIAL
+# ifndef YYLOCATION_PRINT
+
+# if defined YY_LOCATION_PRINT
+
+ /* Temporary convenience wrapper in case some people defined the
+ undocumented and private YY_LOCATION_PRINT macros. */
+# define YYLOCATION_PRINT(File, Loc) YY_LOCATION_PRINT(File, *(Loc))
+
+# elif defined GRAM_LTYPE_IS_TRIVIAL && GRAM_LTYPE_IS_TRIVIAL
/* Print *YYLOCP on YYO. Private, do not rely on its existence. */
@@ -1038,13 +1045,21 @@ yy_location_print_ (FILE *yyo, YYLTYPE const * const yylocp)
return res;
}
-# define YY_LOCATION_PRINT(File, Loc) \
- yy_location_print_ (File, &(Loc))
+# define YYLOCATION_PRINT yy_location_print_
+
+ /* Temporary convenience wrapper in case some people defined the
+ undocumented and private YY_LOCATION_PRINT macros. */
+# define YY_LOCATION_PRINT(File, Loc) YYLOCATION_PRINT(File, &(Loc))
# else
-# define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+
+# define YYLOCATION_PRINT(File, Loc) ((void) 0)
+ /* Temporary convenience wrapper in case some people defined the
+ undocumented and private YY_LOCATION_PRINT macros. */
+# define YY_LOCATION_PRINT YYLOCATION_PRINT
+
# endif
-# endif /* !defined YY_LOCATION_PRINT */
+# endif /* !defined YYLOCATION_PRINT */
# define YY_SYMBOL_PRINT(Title, Kind, Value, Location) \
@@ -1281,7 +1296,7 @@ yy_symbol_print (FILE *yyo,
YYFPRINTF (yyo, "%s %s (",
yykind < YYNTOKENS ? "token" : "nterm", yysymbol_name (yykind));
- YY_LOCATION_PRINT (yyo, *yylocationp);
+ YYLOCATION_PRINT (yyo, yylocationp);
YYFPRINTF (yyo, ": ");
yy_symbol_value_print (yyo, yykind, yyvaluep, yylocationp);
YYFPRINTF (yyo, ")");
@@ -1003,12 +1003,19 @@ do { \
} while (0)
-/* YY_LOCATION_PRINT -- Print the location on the stream.
+/* YYLOCATION_PRINT -- Print the location on the stream.
This macro was not mandated originally: define only if we know
we won't break user code: when these are the locations we know. */